@@ -7,10 +7,12 @@ use pbkdf2::{
 use rand_core::OsRng;
 use sha1::Sha1;
 use sha2::{Sha256, Sha512};
+#[cfg(target_arch = "wasm32")]
 use wasm_bindgen::prelude::*;
+#[cfg(target_arch = "wasm32")]
 use wasm_bindgen::{throw_str, JsValue};
 
-#[wasm_bindgen]
+#[cfg_attr(target_arch = "wasm32", wasm_bindgen)]
 #[derive(Debug, Clone, Copy)]
 pub enum PBKDF2Hashes {
     SHA1,
@@ -43,7 +45,7 @@ impl KDF {
     }
 }
 
-#[wasm_bindgen]
+#[cfg_attr(target_arch = "wasm32", wasm_bindgen)]
 impl KDF {
     /**
      * Implementation of PBKDF2 - when None is specified for salt, a random salt will be generated
