@@ -1,12 +1,13 @@
-use crate::{BSVErrors, P2PKHAddress, Signature, SigningHash, ECDSA};
+use crate::{BSVErrors, ECIESCiphertext, P2PKHAddress, Signature, SigningHash, ECDSA, ECIES};
 
 use elliptic_curve::sec1::*;
 use k256::Secp256k1;
+#[cfg(target_arch = "wasm32")]
 use wasm_bindgen::{prelude::*, throw_str};
 
 use crate::PrivateKey;
 
-#[wasm_bindgen]
+#[cfg_attr(target_arch = "wasm32", wasm_bindgen)]
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub struct PublicKey {
     point: Vec<u8>,
@@ -23,7 +24,7 @@ impl PublicKey {
 
     pub(crate) fn to_hex_impl(&self) -> Result<String, BSVErrors> {
         let bytes = self.to_bytes_impl()?;
-        return Ok(hex::encode(bytes));
+        Ok(hex::encode(bytes))
     }
 
     pub(crate) fn to_bytes_impl(&self) -> Result<Vec<u8>, BSVErrors> {
@@ -59,7 +60,7 @@ impl PublicKey {
 
     pub(crate) fn from_hex_impl(hex_str: &str) -> Result<PublicKey, BSVErrors> {
         let point_bytes = hex::decode(hex_str)?;
-        Ok(PublicKey::from_bytes_impl(&point_bytes)?)
+        PublicKey::from_bytes_impl(&point_bytes)
     }
 
     /**
@@ -72,19 +73,23 @@ impl PublicKey {
     pub(crate) fn to_p2pkh_address_impl(&self) -> Result<P2PKHAddress, BSVErrors> {
         P2PKHAddress::from_pubkey_impl(self)
     }
+
+    /**
+     * Encrypt a message to be sent to this public key with the provided private key.
+     */
+    pub(crate) fn encrypt_message_impl(&self, message: &[u8], sender_private_key: &PrivateKey) -> Result<ECIESCiphertext, BSVErrors> {
+        ECIES::encrypt_impl(message, sender_private_key, self, false)
+    }
 }
 
-#[wasm_bindgen]
+#[cfg_attr(target_arch = "wasm32", wasm_bindgen)]
 impl PublicKey {
-    #[wasm_bindgen(js_name = isValidMessage)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = isValidMessage))]
     pub fn is_valid_message(&self, message: &[u8], signature: &Signature) -> bool {
-        match self.verify_message_impl(message, signature) {
-            Ok(_) => true,
-            Err(_) => false,
-        }
+        self.verify_message_impl(message, signature).is_ok()
     }
 
-    #[wasm_bindgen(js_name = isCompressed)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = isCompressed))]
     pub fn is_compressed(&self) -> bool {
         self.is_compressed
     }
@@ -94,9 +99,9 @@ impl PublicKey {
  * WASM Exported Methods
  */
 #[cfg(target_arch = "wasm32")]
-#[wasm_bindgen]
+#[cfg_attr(target_arch = "wasm32", wasm_bindgen)]
 impl PublicKey {
-    #[wasm_bindgen(js_name = fromHex)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = fromHex))]
     pub fn from_hex(hex_str: &str) -> Result<PublicKey, JsValue> {
         match PublicKey::from_hex_impl(hex_str) {
             Ok(v) => Ok(v),
@@ -104,7 +109,7 @@ impl PublicKey {
         }
     }
 
-    #[wasm_bindgen(js_name = fromBytes)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = fromBytes))]
     pub fn from_bytes(bytes: &[u8]) -> Result<PublicKey, JsValue> {
         match PublicKey::from_bytes_impl(bytes) {
             Ok(v) => Ok(v),
@@ -112,7 +117,7 @@ impl PublicKey {
         }
     }
 
-    #[wasm_bindgen(js_name = toBytes)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = toBytes))]
     pub fn to_bytes(&self) -> Result<Vec<u8>, JsValue> {
         match PublicKey::to_bytes_impl(&self) {
             Ok(v) => Ok(v),
@@ -120,7 +125,7 @@ impl PublicKey {
         }
     }
 
-    #[wasm_bindgen(js_name = toHex)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = toHex))]
     pub fn to_hex(&self) -> Result<String, JsValue> {
         match PublicKey::to_hex_impl(&self) {
             Ok(v) => Ok(v),
@@ -128,12 +133,12 @@ impl PublicKey {
         }
     }
 
-    #[wasm_bindgen(js_name = fromPrivateKey)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = fromPrivateKey))]
     pub fn from_private_key(priv_key: &PrivateKey) -> PublicKey {
         PublicKey::from_private_key_impl(priv_key)
     }
 
-    #[wasm_bindgen(js_name = verifyMessage)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = verifyMessage))]
     pub fn verify_message(&self, message: &[u8], signature: &Signature) -> Result<bool, JsValue> {
         match self.verify_message_impl(message, signature) {
             Ok(v) => Ok(v),
@@ -141,7 +146,7 @@ impl PublicKey {
         }
     }
 
-    #[wasm_bindgen(js_name = toAddress)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = toAddress))]
     pub fn to_p2pkh_address(&self) -> Result<P2PKHAddress, JsValue> {
         match self.to_p2pkh_address_impl() {
             Ok(v) => Ok(v),
@@ -149,7 +154,7 @@ impl PublicKey {
         }
     }
 
-    #[wasm_bindgen(js_name = toCompressed)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = toCompressed))]
     pub fn to_compressed(&self) -> Result<PublicKey, JsValue> {
         match self.to_compressed_impl() {
             Ok(v) => Ok(v),
@@ -157,13 +162,21 @@ impl PublicKey {
         }
     }
 
-    #[wasm_bindgen(js_name = toDecompressed)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = toDecompressed))]
     pub fn to_decompressed(&self) -> Result<PublicKey, JsValue> {
         match self.to_decompressed_impl() {
             Ok(v) => Ok(v),
             Err(e) => throw_str(&e.to_string()),
         }
     }
+
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = encryptMessage))]
+    pub fn encrypt_message(&self, message: &[u8], sender_private_key: &PrivateKey) -> Result<ECIESCiphertext, JsValue> {
+        match self.encrypt_message_impl(message, sender_private_key) {
+            Ok(v) => Ok(v),
+            Err(e) => throw_str(&e.to_string()),
+        }
+    }
 }
 
 /**
@@ -180,11 +193,11 @@ impl PublicKey {
     }
 
     pub fn to_bytes(&self) -> Result<Vec<u8>, BSVErrors> {
-        PublicKey::to_bytes_impl(&self)
+        PublicKey::to_bytes_impl(self)
     }
 
     pub fn to_hex(&self) -> Result<String, BSVErrors> {
-        PublicKey::to_hex_impl(&self)
+        PublicKey::to_hex_impl(self)
     }
 
     pub fn from_private_key(priv_key: &PrivateKey) -> PublicKey {
@@ -206,4 +219,8 @@ impl PublicKey {
     pub fn to_decompressed(&self) -> Result<PublicKey, BSVErrors> {
         self.to_decompressed_impl()
     }
+
+    pub fn encrypt_message(&self, message: &[u8], sender_private_key: &PrivateKey) -> Result<ECIESCiphertext, BSVErrors> {
+        self.encrypt_message_impl(message, sender_private_key)
+    }
 }
