@@ -8,12 +8,13 @@ use crate::{
     Script, VarInt,
 };
 use serde::*;
+#[cfg(target_arch = "wasm32")]
 use wasm_bindgen::{prelude::*, throw_str, JsValue};
 
 use byteorder::*;
 use thiserror::*;
 
-#[wasm_bindgen]
+#[cfg_attr(target_arch = "wasm32", wasm_bindgen)]
 #[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize)]
 pub struct TxIn {
     #[serde(serialize_with = "to_hex", deserialize_with = "from_hex")]
@@ -141,9 +142,9 @@ impl TxIn {
  * Platform Agnostic Functions
  * ie. Don't need Result<T, E>
  */
-#[wasm_bindgen]
+#[cfg_attr(target_arch = "wasm32", wasm_bindgen)]
 impl TxIn {
-    #[wasm_bindgen(constructor)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(constructor))]
     pub fn new(prev_tx_id: &[u8], vout: u32, script_sig: &Script, sequence: Option<u32>) -> TxIn {
         TxIn {
             prev_tx_id: prev_tx_id.to_vec(),
@@ -158,7 +159,7 @@ impl TxIn {
         }
     }
 
-    #[wasm_bindgen(js_name = getPrevTxId)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = getPrevTxId))]
     pub fn get_prev_tx_id(&self, little_endian: Option<bool>) -> Vec<u8> {
         match little_endian {
             Some(true) => {
@@ -170,89 +171,89 @@ impl TxIn {
         }
     }
 
-    #[wasm_bindgen(js_name = getPrevTxIdHex)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = getPrevTxIdHex))]
     pub fn get_prev_tx_id_hex(&self, little_endian: Option<bool>) -> String {
         hex::encode(self.get_prev_tx_id(little_endian))
     }
 
-    #[wasm_bindgen(js_name = getVOut)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = getVOut))]
     pub fn get_vout(&self) -> u32 {
         self.vout
     }
 
-    #[wasm_bindgen(js_name = getScriptSigSize)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = getScriptSigSize))]
     pub fn get_script_sig_size(&self) -> u64 {
         self.script_sig.0.len() as u64
     }
 
-    #[wasm_bindgen(js_name = getScriptSig)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = getScriptSig))]
     pub fn get_script_sig(&self) -> Script {
         self.script_sig.clone()
     }
 
-    #[wasm_bindgen(js_name = getScriptSigHex)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = getScriptSigHex))]
     pub fn get_script_sig_hex(&self) -> String {
         hex::encode(self.script_sig.0.clone())
     }
 
-    #[wasm_bindgen(js_name = getSequence)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = getSequence))]
     pub fn get_sequence(&self) -> u32 {
         self.sequence
     }
 
-    #[wasm_bindgen(js_name = getSequenceAsBytes)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = getSequenceAsBytes))]
     pub fn get_sequence_as_bytes(&self) -> Vec<u8> {
         self.sequence.to_be_bytes().to_vec()
     }
 
-    #[wasm_bindgen(js_name = getOutpointBytes)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = getOutpointBytes))]
     pub fn get_outpoint_bytes(&self, little_endian: Option<bool>) -> Vec<u8> {
         let mut outpoint_bytes = self.get_prev_tx_id(little_endian);
         outpoint_bytes.extend_from_slice(&self.vout.to_le_bytes());
         outpoint_bytes
     }
 
-    #[wasm_bindgen(js_name = getOutpointHex)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = getOutpointHex))]
     pub fn get_outpoint_hex(&self, little_endian: Option<bool>) -> String {
         hex::encode(self.get_outpoint_bytes(little_endian))
     }
 
-    #[wasm_bindgen(js_name = setScript)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = setScript))]
     pub fn set_script(&mut self, script: &Script) {
         self.script_sig = script.clone();
     }
 
-    #[wasm_bindgen(js_name = setPrevTxId)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = setPrevTxId))]
     pub fn set_prev_tx_id(&mut self, txid: &[u8]) {
         self.prev_tx_id = txid.to_vec();
     }
 
-    #[wasm_bindgen(js_name = setVOut)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = setVOut))]
     pub fn set_vout(&mut self, vout: u32) {
         self.vout = vout;
     }
 
-    #[wasm_bindgen(js_name = setSequence)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = setSequence))]
     pub fn set_sequence(&mut self, sequence: u32) {
         self.sequence = sequence;
     }
 
-    #[wasm_bindgen(js_name = setSatoshis)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = setSatoshis))]
     pub fn set_satoshis(&mut self, satoshis: u64) {
         self.satoshis = Some(satoshis);
     }
 
-    #[wasm_bindgen(js_name = getSatoshis)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = getSatoshis))]
     pub fn get_satoshis(&self) -> Option<u64> {
         self.satoshis
     }
 
-    #[wasm_bindgen(js_name = setUnlockingScript)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = setUnlockingScript))]
     pub fn set_unlocking_script(&mut self, unlocking_script: &Script) {
         self.unlocking_script = Some(unlocking_script.clone());
     }
 
-    #[wasm_bindgen(js_name = getUnlockingScriptBytes)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = getUnlockingScriptBytes))]
     pub fn get_unlocking_script_bytes(&self) -> Option<Vec<u8>> {
         self.unlocking_script.as_ref().map(|v| v.to_bytes())
     }
@@ -262,9 +263,9 @@ impl TxIn {
  * WASM Specific Functions
  */
 #[cfg(target_arch = "wasm32")]
-#[wasm_bindgen]
+#[cfg_attr(target_arch = "wasm32", wasm_bindgen)]
 impl TxIn {
-    #[wasm_bindgen(js_name = fromHex)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = fromHex))]
     pub fn from_hex(hex_str: &str) -> Result<TxIn, JsValue> {
         match TxIn::from_hex_impl(hex_str) {
             Ok(v) => Ok(v),
@@ -272,7 +273,7 @@ impl TxIn {
         }
     }
 
-    #[wasm_bindgen(js_name = toJSON)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = toJSON))]
     pub fn to_json(&self) -> Result<JsValue, JsValue> {
         match JsValue::from_serde(&self) {
             Ok(v) => Ok(v),
@@ -280,7 +281,7 @@ impl TxIn {
         }
     }
 
-    #[wasm_bindgen(js_name = toString)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = toString))]
     pub fn to_json_string(&self) -> Result<String, JsValue> {
         match TxIn::to_json_string_impl(&self) {
             Ok(v) => Ok(v),
@@ -288,7 +289,7 @@ impl TxIn {
         }
     }
 
-    #[wasm_bindgen(js_name = toBytes)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = toBytes))]
     pub fn to_bytes(&self) -> Result<Vec<u8>, JsValue> {
         match TxIn::to_bytes_impl(&self) {
             Ok(v) => Ok(v),
@@ -296,7 +297,7 @@ impl TxIn {
         }
     }
 
-    #[wasm_bindgen(js_name = toHex)]
+    #[cfg_attr(target_arch = "wasm32", wasm_bindgen(js_name = toHex))]
     pub fn to_hex(&self) -> Result<String, JsValue> {
         match TxIn::to_hex_impl(&self) {
             Ok(v) => Ok(v),
